# anormalratingsystem

[![GitHub tag (latest by date)](https://img.shields.io/github/v/tag/unkokaeru/anormalratingsystem?label=version)](https://github.com/unkokaeru/anormalratingsystem)
[![Lines Of Code](https://tokei.rs/b1/github/unkokaeru/anormalratingsystem?category=code)](https://github.com/unkokaeru/anormalratingsystem)
[![Continuous Integration (CI) Tests](https://img.shields.io/github/actions/workflow/status/unkokaeru/anormalratingsystem/continuous_integration.yml?label=tests)](https://github.com/unkokaeru/anormalratingsystem)
[![GitHub last commit](https://img.shields.io/github/last-commit/unkokaeru/anormalratingsystem)](https://github.com/unkokaeru/anormalratingsystem)

Rate anything from a scale of 1-10 with simple comparisons! The end result is even normally distributed. Do you like A better than B?

- [anormalratingsystem](#anormalratingsystem)
    - [Features](#features)
    - [Installation](#installation)
    - [Usage](#usage)
    - [Documentation](#documentation)
    - [Contributing](#contributing)
    - [License](#license)

## Features

- [x] Installable via pip
- [x] Command-line interface
- [x] Interactive documentation
- [ ] Rate anything through comparisons
- [ ] Multiple rating systems, 1-10, A-F, etc.
- [ ] Auto-export to Anilist/MyAnimeList support formats.

## Installation

To install anormalratingsystem, simply run:

```bash
pip install anormalratingsystem
```

## Usage

After installation, you can use anormalratingsystem by running:

```bash
$ python3 -m anormalratingsystem
# or
$ anormalratingsystem
```

## Documentation
For more information, you can find the documentation within the [docs](./docs/index.html) directory or on the project's [GitHub Pages](https://unkokaeru.github.io/anormalratingsystem/).

## Contributing

Contributions are welcome! Please refer to our [CONTRIBUTING.md](./CONTRIBUTING.md) for more information.

## License

This project is licensed under the MIT License - see the [LICENSE](./LICENSE) file for details.